@@ -17,9 +17,9 @@ c     Algorithm A G Chetwynd  P J Diggle
       area=plarea(xp,yp,np)
       area=area**2
 
-      dn1=dfloat(n1)
-      dn2=dfloat(n2)
-      dn=dfloat(n)
+      dn1=dble(n1)
+      dn2=dble(n2)
+      dn=dble(n)
       dn12=dn1*(dn1-1.0d0)
       dn22=dn2*(dn2-1.0d0)
       do i=2,n
